#define VERSION		"0.02"
#define NAME		"q2-wrapper"
#define YEAR		"1998"
#define AUTHOR		"David Griffith"
#define EMAIL		"dgriffi@ultrix6.cs.csubak.edu"

#define SOFT		0
#define SOFTX		1
#define	GL		2
#define	GLX		3

#define LINELEN        200
#define PATHLEN         50	/* max length of a path */
#define RENDLEN         8	/* rendering lib name maxlength */
#define NAMELEN		15	/* max length of a filename considered by q2-wrapper */
#define DEV_PATHLEN	15	/* max length of a device filename path */
#define ENVLEN		80	/* max length of an environmental var */

/* Used with quit_verbosity.  Set quit_verbosity before calling exit(3). */
#define TERSE_QUIT	0	/* Output nothing on exit. */
#define SMALL_QUIT	1	/* ==== Q2-wrapper exiting ==== */
#define BIG_QUIT	2	/* SMALL_QUIT plus greeting() */


#define SYS_CONFIG_CHOICE	0
#define USER_CONFIG_CHOICE	1


#define COMMENTLEN	2
#define COMMENT1	'#'
#define COMMENT2	"//"


/*
 * These are the directories in $HOME.
 */

struct directories {
	char home[PATHLEN+1];
	char dot[PATHLEN+1];
	char save[PATHLEN+1];
	char pic[PATHLEN+1];
	char demo[PATHLEN+1];
	char players[PATHLEN+1];
	char video[PATHLEN+1];
};

struct settings {
	char basedir[PATHLEN+1];	/* /usr/games/quake2 */
	char user_dir[PATHLEN+1];	/* usually ".quake2" */
	char sys_baseq2[PATHLEN+1];	/* /usr/games/quake2/sys_baseq2 */
					/* the real baseq2.  Stuff in */
					/* $HOME/.quake2 point to stuff here */

	char binpath[PATHLEN+1];	/* /usr/local/bin/quake2 */
	char cddir[PATHLEN+1];		/* /cdrom or /mnt/cdrom */
	char cd_dev[DEV_PATHLEN+1];	/* /dev/cdrom */

	char user_config[PATHLEN+1];	/* useless? */
	char baseq2[PATHLEN+1];		/* useless? */
	char sys_playersdir[PATHLEN+1];	/* useless? */


	char savedir[PATHLEN+1];	/* save */
	char picdir[PATHLEN+1];		/* scrnshot */
	char demodir[PATHLEN+1];	/* demos */
	char playersdir[PATHLEN+1];	/* players */
	char videodir[PATHLEN+1];	/* video */

	char vid_ref[PATHLEN+1];	/* user-definable */

	int nocdaudio;
	int sndbits;
	int sndspeed;
	int sndchannels;
	int nostdout;

/* I'm not sure how to implement these... */
/*
	int dirmode;	
	int filemode;
*/
};


extern struct directories dir;
extern struct settings config; 

extern int	quit_verbosity;


/************************************************************************
 *									*
 * Function Prototypes							*
 *									*
 ************************************************************************/

void greetings(void);
/*
 * Spew some greetings
 *
 ************************************************************************/

void die(void);
/*
 * Print "==== Q2-wrapper exiting ====" really nicely.  Never returns.
 *
 ************************************************************************/

void usage(char *);
/*
 * Print usage message.  Never returns.
 * 
 * Parameters:
 * 	1.  argv[0]
 * 
 ************************************************************************/

void makeline(char *, int, char **);
/*
 * Convert the command line struct into the actual string passed to the
 * quake2 binary.
 *
 ************************************************************************/

/*int checkdisplay(struct commandline *); */
int checkdisplay(void);
/*
 * Check if we're in X11 or SVGALIB.  
 *
 * Return values:
 *		REF_SOFT	Software rendering on the console.
 *		REF_GL		OpenGL rendering on the console
 *		REF_SOFTX	Software rendering in X11
 *		REF_GLX		OpenGL rendering in X11 (not supported yet)
 *		REF_GGI		GGI rendering (not supported yet)
 *
 ************************************************************************/


int getpaths(void);
/*
 * Load up struct directories dir with paths and stuff.  Should be done
 * before creating .quake2/ and friends, manipulating stuff in
 * BASEDIR/SYS-BASE or .quake2/
 *
 * Return values:
 *	1	$HOME exists.
 *	-1	$HOME doesn't exist.  This shouldn't happen.
 *
 ************************************************************************/

int checkdirs(void);
/* 
 * See if the q2-wrapper directories exist.  If not, make them.  It's
 * important to create these directories explicitly, otherwise Quake2 will
 * create them in basedir and muck up everything. 
 *
 * ln -s BASEDIR/sys-baseq2/players/male $HOME/.quake2/players/male
 * ln -s BASEDIR/sys-baseq2/players/female $HOME/.quake2/players/female
 *
 * The above allows the user to use the system skins (which are
 * unchangable by lusers) AND have his own skins in
 * $HOME/.quake2/players/<foo>/.
 *
 * If any of these directories or symlinks are removed, they are recreated
 * the next time q2-wrapper is run.
 *
 * Return values:
 *	1	$HOME/.quake2 exists and the contents make sense.
 *	-1	Doesn't make sense.  
 *
 ************************************************************************/

int makelinks(void);
/*
 * Instead of saves, screenshots, etc being in BASEDIR/baseq2, they'll be
 * in $HOME/.quake2 instead.  This and breaklinks are seperate
 * functions because some day I may want to doing more stuff in here.
 *
 * ln -s $HOME/.quake2 BASEDIR/baseq2
 *
 * Return values:
 *	1	Linkup went okay.
 *	-1	Something went wrong.
 *
 ************************************************************************/

int breaklinks(void);
/*
 * These symlinks must be removed for the next player to use his own
 * settings.  No, I'm not doing system("rm -f blahblah");
 *
 * rm -f BASEDIR/baseq2
 *
 * Return values:
 *	1	Went okay.
 *	-1	Something went wrong.
 *
 ************************************************************************/

int initconfigvars(struct settings *);
/*
 * Initialize a settings structure.  Blank it all out.
 *
 * Parameters:
 * 	1.  	a setting structure, probably the only one.  Doesn't muck
 *		with globalism for sanity's sake.
 *
 * Return values:
 * 	1	No meaning here yet.
 * 
 ************************************************************************/

int getconfig(int);
/*
 * Fill the global or user config structure variable from settings in
 * the system config file or user config file.  We should be using
 * /etc/q2-wrapper.conf for the system config file and
 * $HOME/quake2/q2-wrapper.conf for the user's config file.  If a user's
 * config file contains user-settable settings that contradict the system
 * config file's settings, the user's settings win.
 * 
 * Parameters:
 *	1.	SYS_CONFIG_CHOICE or USER_CONFIG_CHOICE
 *		Choice determines which config file to process.
 *
 * Return values:
 *	1	Went okay.
 *	-1	Couldn't read the file.  This should be fatal if we're    
 *		reading the system file.  Don't worry if it's the user's
 *		file.
 * 
 ************************************************************************/

